@@ -428,7 +428,7 @@ verify(GNUTLS_EXTENSION_MAX < MAX_EXT_TYPES);
  */
 verify(GNUTLS_EXTENSION_MAX_VALUE - GNUTLS_EXTENSION_MAX >= 16);
 
-/* MAX_EXT_TYPES + 1 must fit in a single byte, to generate random
+/* MAX_EXT_TYPES must fit in a single byte, to generate random
  * permutation at once.
  */
 verify(MAX_EXT_TYPES <= UINT8_MAX);
@@ -594,6 +594,7 @@ struct gnutls_key_st {
 		gnutls_pk_params_st ecdh_params;
 		gnutls_pk_params_st ecdhx_params;
 		gnutls_pk_params_st dh_params;
+		gnutls_pk_params_st kem_params;
 	} kshare;
 
 	/* The union contents depend on the negotiated protocol.
@@ -764,6 +765,7 @@ typedef struct gnutls_group_entry_st {
 	const unsigned *q_bits;
 	gnutls_ecc_curve_t curve;
 	gnutls_pk_algorithm_t pk;
+	gnutls_pk_algorithm_t pk2;
 	unsigned tls_id; /* The RFC4492 namedCurve ID or TLS 1.3 group ID */
 } gnutls_group_entry_st;
 
@@ -777,6 +779,8 @@ typedef struct gnutls_group_entry_st {
 #define GNUTLS_MAC_FLAG_ALLOW_INSECURE_REVERTIBLE \
 	(1                                        \
 	 << 3) /* when checking with _gnutls_digest_is_insecure2, don't treat revertible setting as fatal */
+#define GNUTLS_MAC_FLAG_XOF \
+	(1 << 4) /* this function is an extendable output function (XOF) */
 /* This structure is used both for MACs and digests
  */
 typedef struct mac_entry_st {
