@@ -21,7 +21,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include <stdlib.h>
@@ -42,9 +42,9 @@
 
 static int sec_param[MAX_TRIES] =
 #ifdef ENABLE_FIPS140
-    { GNUTLS_SEC_PARAM_MEDIUM, GNUTLS_SEC_PARAM_HIGH };
+	{ GNUTLS_SEC_PARAM_MEDIUM, GNUTLS_SEC_PARAM_HIGH };
 #else
-    { GNUTLS_SEC_PARAM_LOW, GNUTLS_SEC_PARAM_MEDIUM };
+	{ GNUTLS_SEC_PARAM_LOW, GNUTLS_SEC_PARAM_MEDIUM };
 #endif
 
 static void tls_log_func(int level, const char *str)
@@ -52,12 +52,10 @@ static void tls_log_func(int level, const char *str)
 	fprintf(stderr, "%s |<%d>| %s", "privkey-keygen", level, str);
 }
 
-const gnutls_datum_t raw_data = {
-	(void *) "hello there",
-	11
-};
+const gnutls_datum_t raw_data = { (void *)"hello there", 11 };
 
-static void sign_verify_data(gnutls_pk_algorithm_t algorithm, gnutls_x509_privkey_t pkey)
+static void sign_verify_data(gnutls_pk_algorithm_t algorithm,
+			     gnutls_x509_privkey_t pkey)
 {
 	int ret;
 	gnutls_privkey_t privkey;
@@ -78,7 +76,7 @@ static void sign_verify_data(gnutls_pk_algorithm_t algorithm, gnutls_x509_privke
 	if (ret < 0)
 		fail("gnutls_pubkey_import_privkey\n");
 
-	ret = gnutls_pubkey_get_preferred_hash_algorithm (pubkey, &digest, NULL);
+	ret = gnutls_pubkey_get_preferred_hash_algorithm(pubkey, &digest, NULL);
 	if (ret < 0)
 		fail("gnutls_pubkey_get_preferred_hash_algorithm\n");
 
@@ -86,14 +84,17 @@ static void sign_verify_data(gnutls_pk_algorithm_t algorithm, gnutls_x509_privke
 		vflags |= GNUTLS_VERIFY_ALLOW_BROKEN;
 
 	/* sign arbitrary data */
-	ret = gnutls_privkey_sign_data(privkey, digest, 0,
-					&raw_data, &signature);
+	ret = gnutls_privkey_sign_data(privkey, digest, 0, &raw_data,
+				       &signature);
 	if (ret < 0)
 		fail("gnutls_privkey_sign_data\n");
 
 	/* verify data */
-	ret = gnutls_pubkey_verify_data2(pubkey, gnutls_pk_to_sign(gnutls_pubkey_get_pk_algorithm(pubkey, NULL),digest),
-				         vflags, &raw_data, &signature);
+	ret = gnutls_pubkey_verify_data2(
+		pubkey,
+		gnutls_pk_to_sign(gnutls_pubkey_get_pk_algorithm(pubkey, NULL),
+				  digest),
+		vflags, &raw_data, &signature);
 	if (ret < 0)
 		fail("gnutls_pubkey_verify_data2\n");
 
@@ -102,11 +103,12 @@ static void sign_verify_data(gnutls_pk_algorithm_t algorithm, gnutls_x509_privke
 	gnutls_free(signature.data);
 }
 
-static unsigned int
-is_approved_pk_algo(gnutls_pk_algorithm_t algo) {
+static unsigned int is_approved_pk_algo(gnutls_pk_algorithm_t algo)
+{
 	switch (algo) {
 	case GNUTLS_PK_RSA:
 	case GNUTLS_PK_RSA_PSS:
+	case GNUTLS_PK_RSA_OAEP:
 	case GNUTLS_PK_EC:
 		return 1;
 	default:
@@ -119,30 +121,6 @@ void doit(void)
 	gnutls_x509_privkey_t pkey, dst;
 	int ret, algorithm, i;
 	gnutls_fips140_context_t fips_context;
-	gnutls_fips140_operation_state_t fips_state;
-
-#define FIPS_PUSH_CONTEXT() do {					\
-	if (gnutls_fips140_mode_enabled()) {				\
-		ret = gnutls_fips140_push_context(fips_context);	\
-		if (ret < 0) {						\
-			fail("gnutls_fips140_push_context failed\n");	\
-		}							\
-	}								\
-} while (0)
-
-#define FIPS_POP_CONTEXT(state) do {					\
-	if (gnutls_fips140_mode_enabled()) {				\
-		ret = gnutls_fips140_pop_context();			\
-		if (ret < 0) {						\
-			fail("gnutls_fips140_context_pop failed\n");	\
-		}							\
-		fips_state = gnutls_fips140_get_operation_state(fips_context); \
-		if (fips_state != GNUTLS_FIPS140_OP_ ## state) {	\
-			fail("operation state is not " # state " (%d)\n", \
-			     fips_state);				\
-		}							\
-	}								\
-} while (0)
 
 	ret = global_init();
 	if (ret < 0)
@@ -161,6 +139,9 @@ void doit(void)
 		for (algorithm = GNUTLS_PK_RSA; algorithm <= GNUTLS_PK_MAX;
 		     algorithm++) {
 			if (algorithm == GNUTLS_PK_DH ||
+#ifndef ENABLE_DSA
+			    algorithm == GNUTLS_PK_DSA ||
+#endif
 			    algorithm == GNUTLS_PK_ECDH_X25519 ||
 			    algorithm == GNUTLS_PK_ECDH_X448)
 				continue;
@@ -182,30 +163,30 @@ void doit(void)
 
 			ret = gnutls_x509_privkey_init(&pkey);
 			if (ret < 0) {
-				fail("gnutls_x509_privkey_init: %d\n",
-				     ret);
+				fail("gnutls_x509_privkey_init: %d\n", ret);
 			}
 
 			ret = gnutls_x509_privkey_init(&dst);
 			if (ret < 0) {
-				fail("gnutls_x509_privkey_init: %d\n",
-				     ret);
+				fail("gnutls_x509_privkey_init: %d\n", ret);
 			}
 
 			FIPS_PUSH_CONTEXT();
-			ret =
-			    gnutls_x509_privkey_generate(pkey, algorithm,
-							 gnutls_sec_param_to_pk_bits
-							 (algorithm,
-							  sec_param[i]),
-							 0);
+			ret = gnutls_x509_privkey_generate(
+				pkey, algorithm,
+				gnutls_sec_param_to_pk_bits(algorithm,
+							    sec_param[i]),
+				0);
 			if (ret < 0) {
-				fail("gnutls_x509_privkey_generate (%s-%d): %s (%d)\n", gnutls_pk_algorithm_get_name(algorithm),
-					gnutls_sec_param_to_pk_bits(algorithm,sec_param[i]), gnutls_strerror(ret), ret);
+				fail("gnutls_x509_privkey_generate (%s-%d): %s (%d)\n",
+				     gnutls_pk_algorithm_get_name(algorithm),
+				     gnutls_sec_param_to_pk_bits(algorithm,
+								 sec_param[i]),
+				     gnutls_strerror(ret), ret);
 			} else if (debug) {
 				success("Key[%s] generation ok: %d\n",
-					gnutls_pk_algorithm_get_name
-					(algorithm), ret);
+					gnutls_pk_algorithm_get_name(algorithm),
+					ret);
 			}
 			if (is_approved_pk_algo(algorithm)) {
 				FIPS_POP_CONTEXT(APPROVED);
@@ -215,18 +196,29 @@ void doit(void)
 
 			ret = gnutls_x509_privkey_verify_params(pkey);
 			if (ret < 0) {
-				fail("gnutls_x509_privkey_generate (%s): %s (%d)\n", gnutls_pk_algorithm_get_name(algorithm), gnutls_strerror(ret), ret);
+				fail("gnutls_x509_privkey_generate (%s): %s (%d)\n",
+				     gnutls_pk_algorithm_get_name(algorithm),
+				     gnutls_strerror(ret), ret);
 			}
 
 			/* include test of cpy */
 			ret = gnutls_x509_privkey_cpy(dst, pkey);
 			if (ret < 0) {
-				fail("gnutls_x509_privkey_cpy (%s): %s (%d)\n", gnutls_pk_algorithm_get_name(algorithm), gnutls_strerror(ret), ret);
+				fail("gnutls_x509_privkey_cpy (%s): %s (%d)\n",
+				     gnutls_pk_algorithm_get_name(algorithm),
+				     gnutls_strerror(ret), ret);
 			}
 
 			ret = gnutls_x509_privkey_verify_params(pkey);
 			if (ret < 0) {
-				fail("gnutls_x509_privkey_generate after cpy (%s): %s (%d)\n", gnutls_pk_algorithm_get_name(algorithm), gnutls_strerror(ret), ret);
+				fail("gnutls_x509_privkey_generate after cpy (%s): %s (%d)\n",
+				     gnutls_pk_algorithm_get_name(algorithm),
+				     gnutls_strerror(ret), ret);
+			}
+
+			/* RSA-OAEP doesn't support signing */
+			if (algorithm == GNUTLS_PK_RSA_OAEP) {
+				goto end;
 			}
 
 			FIPS_PUSH_CONTEXT();
@@ -245,9 +237,13 @@ void doit(void)
 				FIPS_POP_CONTEXT(NOT_APPROVED);
 			}
 
+		end:
 			gnutls_x509_privkey_deinit(pkey);
 			gnutls_x509_privkey_deinit(dst);
-			success("Generated key with %s-%d\n", gnutls_pk_algorithm_get_name(algorithm), gnutls_sec_param_to_pk_bits(algorithm,sec_param[i]));
+			success("Generated key with %s-%d\n",
+				gnutls_pk_algorithm_get_name(algorithm),
+				gnutls_sec_param_to_pk_bits(algorithm,
+							    sec_param[i]));
 		}
 	}
 
