@@ -16,14 +16,13 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GnuTLS; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ * along with GnuTLS.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 /* Parts copied from GnuTLS example programs. */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include <stdio.h>
@@ -70,14 +69,13 @@ void doit(void)
 	assert(gnutls_certificate_allocate_credentials(&clicred) >= 0);
 	gnutls_certificate_allocate_credentials(&x509_cred);
 
-	ret = gnutls_certificate_set_x509_trust_mem(clicred, &ca3_cert, GNUTLS_X509_FMT_PEM);
+	ret = gnutls_certificate_set_x509_trust_mem(clicred, &ca3_cert,
+						    GNUTLS_X509_FMT_PEM);
 	if (ret < 0)
 		fail("set_x509_trust_file failed: %s\n", gnutls_strerror(ret));
 
-
-	ret = gnutls_certificate_set_x509_key_mem(x509_cred, &cli_cert,
-					    &server_key,
-					    GNUTLS_X509_FMT_PEM);
+	ret = gnutls_certificate_set_x509_key_mem(
+		x509_cred, &cli_cert, &server_key, GNUTLS_X509_FMT_PEM);
 	if (ret != GNUTLS_E_CERTIFICATE_KEY_MISMATCH) {
 		fail("error in error code\n");
 		exit(1);
@@ -87,26 +85,29 @@ void doit(void)
 
 	/* test gnutls_certificate_flags() */
 	gnutls_certificate_allocate_credentials(&x509_cred);
-	gnutls_certificate_set_flags(x509_cred, GNUTLS_CERTIFICATE_SKIP_KEY_CERT_MATCH);
+	gnutls_certificate_set_flags(x509_cred,
+				     GNUTLS_CERTIFICATE_SKIP_KEY_CERT_MATCH);
 
-	ret = gnutls_certificate_set_x509_key_mem(x509_cred, &server_ca3_localhost6_cert_chain,
-					    &server_ca3_key,
-					    GNUTLS_X509_FMT_PEM);
+	ret = gnutls_certificate_set_x509_key_mem(
+		x509_cred, &server_ca3_localhost6_cert_chain, &server_ca3_key,
+		GNUTLS_X509_FMT_PEM);
 	if (ret < 0) {
 		fail("error in error code\n");
 		exit(1);
 	}
 
-	ret = gnutls_certificate_set_x509_key_mem(x509_cred, &server_ca3_localhost_cert_chain,
-					    &server_ca3_key,
-					    GNUTLS_X509_FMT_PEM);
+	ret = gnutls_certificate_set_x509_key_mem(
+		x509_cred, &server_ca3_localhost_cert_chain, &server_ca3_key,
+		GNUTLS_X509_FMT_PEM);
 	if (ret < 0) {
 		fail("error in error code\n");
 		exit(1);
 	}
 
-	test_cli_serv(x509_cred, clicred, "NORMAL", "localhost", NULL, NULL, NULL);
-	test_cli_serv(x509_cred, clicred, "NORMAL", "localhost6", NULL, NULL, NULL);
+	test_cli_serv(x509_cred, clicred, "NORMAL", "localhost", NULL, NULL,
+		      NULL);
+	test_cli_serv(x509_cred, clicred, "NORMAL", "localhost6", NULL, NULL,
+		      NULL);
 
 	gnutls_certificate_free_credentials(x509_cred);
 	gnutls_certificate_free_credentials(clicred);
